@@ -21,13 +21,8 @@ import unittest
 
 import pytest
 
-try:
-    import pyarrow
-except ImportError:  # pragma: NO COVER
-    pyarrow = None
-
 import google.cloud._helpers
-from google.cloud.bigquery import table, enums
+from google.cloud.bigquery import query, table
 from google.cloud.bigquery.dbapi import _helpers
 from google.cloud.bigquery.dbapi import exceptions
 from tests.unit.helpers import _to_pyarrow
@@ -215,7 +210,6 @@ class TestToBqTableRows(unittest.TestCase):
         result = _helpers.to_bq_table_rows(rows_iterable)
         self.assertEqual(list(result), [])
 
-    @unittest.skipIf(pyarrow is None, "Requires `pyarrow`")
     def test_non_empty_iterable(self):
         rows_iterable = [
             dict(
@@ -344,8 +338,8 @@ class TestRaiseOnClosedDecorator(unittest.TestCase):
 
 
 VALID_BQ_TYPES = [
-    (name, getattr(enums.SqlParameterScalarTypes, name)._type)
-    for name in dir(enums.SqlParameterScalarTypes)
+    (name, getattr(query.SqlParameterScalarTypes, name)._type)
+    for name in dir(query.SqlParameterScalarTypes)
     if not name.startswith("_")
 ]
 
